# PyPeakify

PyPeakify is a [Python](https://python.org) package that provides a simple way to perform peak deconvolutions of various spectra.

## Installation

PyPeakify can be installed using [pip](https://pip.pypa.io/en/stable/):

```bash
pip install pypeakify
```

Alternatively, PyPeakify is available on [GitHub](TODO) and can be installed by cloning the repository and running the following command:

```bash
python setup.py sdist
pip install dist/pypeakify-{VERSION}.tar.gz
```

where `{VERSION}` is the version number of the package.

## Usage

See the [usage guide](usage.md) for more information on how to use PyPeakify.

## License

PyPeakify is licensed under the [GPL-3.0](https://github.com/mscloudlab/pypeakify?tab=GPL-3.0-1-ov-file) license.

## Usage in Literature

PyPeakify (or its predecessor, ylftir), has been used in the following publications:

- [Skin repair and infection control in diabetic, obese mice using bioactive laser-activated sealants](https://doi.org/10.1016/j.biomaterials.2024.122668)
